@@ -3,12 +3,13 @@
 """
 
 import re
+from typing import Final
 
-from ._common import preprocess, validate_pathtype
+from ._common import to_str, validate_pathtype
 from .error import InvalidCharError
 
 
-__RE_INVALID_LTSV_LABEL = re.compile("[^0-9A-Za-z_.-]", re.UNICODE)
+__RE_INVALID_LTSV_LABEL: Final = re.compile("[^0-9A-Za-z_.-]", re.UNICODE)
 
 
 def validate_ltsv_label(label: str) -> None:
@@ -21,9 +22,9 @@ def validate_ltsv_label(label: str) -> None:
         If invalid character(s) found in the ``label`` for a LTSV format label.
     """
 
-    validate_pathtype(label, allow_whitespaces=False, error_msg="label is empty")
+    validate_pathtype(label, allow_whitespaces=False)
 
-    match_list = __RE_INVALID_LTSV_LABEL.findall(preprocess(label))
+    match_list = __RE_INVALID_LTSV_LABEL.findall(to_str(label))
     if match_list:
         raise InvalidCharError(f"invalid character found for a LTSV format label: {match_list}")
 
@@ -38,6 +39,6 @@ def sanitize_ltsv_label(label: str, replacement_text: str = "") -> str:
     :rtype: str
     """
 
-    validate_pathtype(label, allow_whitespaces=False, error_msg="label is empty")
+    validate_pathtype(label, allow_whitespaces=False)
 
-    return __RE_INVALID_LTSV_LABEL.sub(replacement_text, preprocess(label))
+    return __RE_INVALID_LTSV_LABEL.sub(replacement_text, to_str(label))
